//! contains everything related to the `FixedBitString` trait.

pub use self::{
	iter::*,
	traits::*,
};

mod iter;
mod traits;
